<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Avvia l&apos;applicazione con il percorso del file immagine come argomento per caricare il file.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>È supportato anche il trascinamento del file immagine sulla finestra.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Nessuna delle operazioni in questa applicazione altererà le immagini sul disco.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>Spiegazione delle opzioni del menu contestuale:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Fai in modo che la finestra rimanga in cima a tutte le altre finestre.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Evitare di chiudere accidentalmente la finestra. (es. facendo doppio clic sulla finestra)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation>Evitare di reimpostare lo stato di zoom/rotazione/capovolgimento applicato alla visualizzazione dell&apos;immagine quando si passa da un&apos;immagine all&apos;altra.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>Versione: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>Logo disegnato da %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Costruito con Qt %1 (%2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>Contributori</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>Elenco dei contributori su GitHub</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Grazie a tutte le persone che hanno contribuito a questo progetto.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>Traduttori</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>Vorrei ringraziare le seguenti persone che si sono offerte volontarie per tradurre questa applicazione.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 si basa sulle seguenti librerie di software libero:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp;Ringraziamenti speciali</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>&amp;Librerie di terze parti</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>I tuoi diritti</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Copyright (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 è rilasciato sotto licenza MIT.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Questa licenza garantisce alle persone una serie di libertà:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>Sei libero di usare %1, per qualsiasi scopo</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>Sei libero di distribuire %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>Puoi studiare come funziona %1 e cambiarlo</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>Puoi distribuire versioni modificate di %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>La licenza MIT ti garantisce questa libertà. A nessuno è mai permesso portarlo via.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>Librerie di terze parti utilizzate da %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>&amp;Licenza</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <location filename="../graphicsscene.cpp" line="100"/>
        <source>Drag image here</source>
        <translation>Trascina qui l&apos;immagine</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <source>File url list is empty</source>
        <translation type="vanished">L&apos;elenco degli URL dei file è vuoto</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="50"/>
        <source>File is not a valid image</source>
        <translation>Il file non è un&apos;immagine valida</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="54"/>
        <location filename="../graphicsview.cpp" line="58"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>I dati dell&apos;immagine non sono validi o non sono attualmente supportati</translation>
    </message>
    <message>
        <source>Image data is invalid</source>
        <translation type="vanished">I dati dell&apos;immagine non sono validi</translation>
    </message>
    <message>
        <source>Not supported mimedata: %1</source>
        <translation type="vanished">Dati mime non supportati: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>File url list is empty</source>
        <translation>L&apos;elenco degli URL dei file è vuoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Image data is invalid</source>
        <translation>I dati dell&apos;immagine non sono validi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Not supported mimedata: %1</source>
        <translation>Dati mime non supportati: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Image From Clipboard</source>
        <translation>Immagine dagli appunti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation>Sei sicuro di voler spostare &quot;%1&quot; nel cestino?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Failed to move file to trash</source>
        <translation>Impossibile spostare il file nel cestino</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation>Lo spostamento nel cestino non è riuscito, potrebbe essere causato da un problema di autorizzazione del file, da una limitazione del file system o da una limitazione della piattaforma.</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Copy P&amp;ixmap</source>
        <translation>Copia P&amp;ixmap</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="115"/>
        <source>Copy &amp;File Path</source>
        <translation>Copia &amp;Percorso file</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="133"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="118"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>Rimani in cima</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>Modalità protetta</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation>Mantieni trasformazione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Zoom in</source>
        <translation>Zoom avanti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Zoom out</source>
        <translation>Zoom indietro</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Pause/Resume Animation</source>
        <translation>Pausa/Riprendi animazione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Animation Go to Next Frame</source>
        <translation>Animazione Vai al fotogramma successivo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Capovolgi &amp;Orizzontalmente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <source>Fit to view</source>
        <translation>Adatto alla visualizzazione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Fit to width</source>
        <translation>Adatta alla larghezza</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="116"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Toggle Checkerboard</source>
        <translation>Attiva/disattiva scacchiera</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Actual size</source>
        <translation>Dimensione reale</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Toggle maximize</source>
        <translation>Attiva massimizzazione</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Rotate right</source>
        <translation>Ruota a destra</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Rotate left</source>
        <translation>Ruota a sinistra</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Previous image</source>
        <translation>Immagine precedente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Next image</source>
        <translation>Immagine successiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Move to Trash</source>
        <translation>Sposta nel cestino</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="121"/>
        <source>Configure...</source>
        <translation>Configura...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="122"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Mostra in Esplora file</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="131"/>
        <source>Show in directory</source>
        <translation>Mostra nella directory</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="134"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>Metadati dell&apos;immagine</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Immagine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Camera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>%1 File</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Foto avanzata</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>Dimensioni</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>Proporzioni</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>Conteggio fotogrammi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>Tipo di elemento</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>Percorso cartella</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>Data di creazione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>Data di modifica</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>Soggetto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>Valutazione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>Tag</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>Commenti</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>Data scatto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>Nome programma</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>Risoluzione orizzontale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>Risoluzione verticale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>Unità di risoluzione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>Rappresentazione del colore</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>Produttore macchina fotografica</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>Modello camera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>F-stop</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>Tempo di esposizione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>Velocità ISO</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>Bias d&apos;esposizione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>Lunghezza focale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>Massima apertura</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>Modalità di misurazione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation>Distanza del soggetto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>Modalità flash</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>Lunghezza focale 35 mm</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>Modello di lente</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation>Contrasto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>Luminosità</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>Programma di esposizione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>Saturazione</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>Nitidezza</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>Bilanciamento del bianco</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>Zoom digitale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>Versione EXIF</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>Riferimento di latitudine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>Latitudine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>Riferimento di longitudine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>Longitudine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>Riferimento altimetrico</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>Altitudine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="31"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="61"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation>Modifica delle scorciatoie per l&apos;azione &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Failed to set shortcuts</source>
        <translation>Impossibile impostare le scorciatoie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation>Controlla se i collegamenti sono duplicati con collegamenti esistenti.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="78"/>
        <source>Do nothing</source>
        <translation>Non fare nulla</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="79"/>
        <source>Close the window</source>
        <translation>Chiudi la finestra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Toggle maximize</source>
        <translation>Attiva massimizzazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Toggle fullscreen</source>
        <translation>Attiva schermo intero</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="85"/>
        <source>Zoom in and out</source>
        <translation>Zoom avanti e indietro</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <source>View next or previous item</source>
        <translation>Visualizza l&apos;elemento successivo o precedente</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>Auto size</source>
        <translation>Dimensione automatica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="91"/>
        <source>Maximized</source>
        <translation>Massimizzato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Windowed</source>
        <translation>Finestrato</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="96"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation>Round (ridimensionamento intero)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="97"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation>Ceil (ridimensionamento intero)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation>Floor (ridimensionamento intero)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation>Segui il sistema (scala frazionaria)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="122"/>
        <source>Stay on top when start-up</source>
        <translation>Rimani in cima quando si avvia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="123"/>
        <source>Use built-in close window animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Use light-color checkerboard</source>
        <translation>Utilizzare scacchiera di colore chiaro</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Loop the loaded gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Double-click behavior</source>
        <translation>Comportamento del doppio clic</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Mouse wheel behavior</source>
        <translation>Comportamento della rotellina del mouse</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Default window size</source>
        <translation>Dimensioni predefinite della finestra</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation>Politica di arrotondamento del fattore di scala HiDPI</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="109"/>
        <source>No shortcuts</source>
        <translation>Nessuna scorciatoia</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="75"/>
        <source>Shortcut #%1</source>
        <translation>Scorciatoia #%1</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>Immagini di Pineapple</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation>Elenca i suffissi dei formati immagine supportati e chiudi il programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>Elenco file.</translation>
    </message>
</context>
</TS>
